GesturePoint class

Constructors

GesturePoint(int index, double centerX, double centerY)

Properties

centerX → double
final
centerY → double
final
hashCode → int
The hash code for this object.
no setteroverride
index → int
final
padding → double
final
radius → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkInside(double x, double y) → bool
drawCircle(Canvas canvas) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

linePainter → Paint
final
pointPainter → Paint
final